<?php
/**
 * ZF Theme functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package ZF_Theme
 */

/**
 * BASE SETUP
 *
 * Set up textdomain, theme-supports, nav menus
 */
require get_template_directory() . '/functions/theme-setup.php';

/**
 * SCRIPTS AND STYLES
 *
 * Enqueue scripts and styles needed by this theme
 */
require get_template_directory() . '/functions/scripts-and-styles.php';

/**
 * FOUNDATION COMPATIBILITY
 */
require get_template_directory() . '/functions/foundation.php';

/**
 * WIDGETS
 *
 * Define widget areas and other widget-related code
 */
require get_template_directory() . '/functions/widgets.php';

/**
 * CUSTOM FIELDS
 *
 * Define custom meta boxes and fields (CMB2)
 */
require get_template_directory() . '/functions/custom-fields.php';

/**
 * CUSTOM HEADER
 *
 * Implement the Custom Header feature. Remove if your theme doesn't need one.
 */
require get_template_directory() . '/functions/custom-header.php';

/**
 * TEMPLATE TAGS
 *
 * Custom template tags for this theme. Any helper functions that output
 * HTML in templates should be in here.
 */
require get_template_directory() . '/functions/template-tags.php';

/**
 * EXTRA FILTERS AND TWEAKS
 *
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/functions/extras.php';

/**
 * CUSTOMIZER
 *
 * Customizer additions.
 */
require get_template_directory() . '/functions/customizer.php';

/**
 * JETPACK
 *
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/functions/jetpack.php';


function the_slug($echo=true){
  $slug = basename(get_permalink());
  do_action('before_slug', $slug);
  $slug = apply_filters('slug_filter', $slug);
  if( $echo ) echo $slug;
  do_action('after_slug', $slug);
  return $slug;
}


// Our custom post type function
function create_posttype() {

	register_post_type( 'gigs',
	// CPT Options
		array(
			'labels' => array(
				'name' => __( 'Gigs' ),
				'singular_name' => __( 'Gig' )
			),
			'public' => true,
			'has_archive' => true,
			'rewrite' => array('slug' => 'gigs'),
			'menu_position'       => 4,
		)
	);
}
// Hooking up our function to theme setup
add_action( 'init', 'create_posttype' );



// submenus
// add hook 
add_filter( 'wp_nav_menu_objects', 'my_wp_nav_menu_objects_sub_menu', 10, 2 );
// filter_hook function to react on sub_menu flag
function my_wp_nav_menu_objects_sub_menu( $sorted_menu_items, $args ) {
  if ( isset( $args->sub_menu ) ) {
    $root_id = 0;
    
    // find the current menu item
    foreach ( $sorted_menu_items as $menu_item ) {
      if ( $menu_item->current ) {
        // set the root id based on whether the current menu item has a parent or not
        $root_id = ( $menu_item->menu_item_parent ) ? $menu_item->menu_item_parent : $menu_item->ID;
        break;
      }
    }
    
    // find the top level parent
    if ( ! isset( $args->direct_parent ) ) {
      $prev_root_id = $root_id;
      while ( $prev_root_id != 0 ) {
        foreach ( $sorted_menu_items as $menu_item ) {
          if ( $menu_item->ID == $prev_root_id ) {
            $prev_root_id = $menu_item->menu_item_parent;
            // don't set the root_id to 0 if we've reached the top of the menu
            if ( $prev_root_id != 0 ) $root_id = $menu_item->menu_item_parent;
            break;
          } 
        }
      }
    }
    $menu_item_parents = array();
    foreach ( $sorted_menu_items as $key => $item ) {
      // init menu_item_parents
      if ( $item->ID == $root_id ) $menu_item_parents[] = $item->ID;
      if ( in_array( $item->menu_item_parent, $menu_item_parents ) ) {
        // part of sub-tree: keep!
        $menu_item_parents[] = $item->ID;
      } else if ( ! ( isset( $args->show_parent ) && in_array( $item->ID, $menu_item_parents ) ) ) {
        // not part of sub-tree: away with it!
        unset( $sorted_menu_items[$key] );
      }
    }
    
    return $sorted_menu_items;
  } else {
    return $sorted_menu_items;
  }
}


//fix wpglobus & ACF conflict

add_filter( 'wpglobus_postdivrich_style', 'filter__wpglobus_postdivrich_style' );
function filter__wpglobus_postdivrich_style( $language ) {
  return 'display:block!important;';
}

// featured image caption

